//
// FlybitsKernelSDK.h
// Copyright (c) :YEAR: Flybits (http://flybits.com)
//
// Permission to use this codebase and all related and dependent interfaces
// are granted as bound by the licensing agreement between Flybits and
// :COMPANY_NAME: effective :EFFECTIVE_DATE:.
//
// Flybits Framework version :VERSION:
// Built: :BUILD_DATE:
//

#import <Foundation/Foundation.h>

//! Project version number for FlybitsKernelSDK.
FOUNDATION_EXPORT double FlybitsKernelSDKVersionNumber;

//! Project version string for FlybitsKernelSDK.
FOUNDATION_EXPORT const unsigned char FlybitsKernelSDKVersionString[];

// In this header, you should import all the public headers of your framework using statements like #import <FlybitsKernelSDK/PublicHeader.h>
